@@ -96,6 +96,10 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     Prompt_Local_Time_list = []
     for idx in df_reprompt.index:
         prompt_local_time_timezone = df_reprompt['Actual_Prompt_Local_Time'][idx]
+        if type(prompt_local_time_timezone) == float:
+            Prompt_Local_Time_list.append(prompt_local_time_timezone)
+            print("float : {}".format(prompt_local_time_timezone))
+            continue
         prompt_local_time_timezone_split = prompt_local_time_timezone.split(" ")
         prompt_local_time_timezone_split_len = len(prompt_local_time_timezone_split)
         if prompt_local_time_timezone_split_len == 3:
@@ -113,15 +117,18 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     prompt_local_time_timezone_split = prompt_local_time_timezone.split(" ")
     prompt_local_time_timezone_split_len = len(prompt_local_time_timezone_split)
     if prompt_local_time_timezone_split_len == 3:
-        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
+        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S") if (type(x) != float) else "NF"
         prompt_dateobject_column = list(map(converter, Prompt_Local_Time_list))
     elif prompt_local_time_timezone_split_len == 6:
-        converter = lambda x: datetime.strptime(x, "%b %d %H:%M:%S %Y")
+        converter = lambda x: datetime.strptime(x, "%b %d %H:%M:%S %Y") if (type(x) != float) else "NF"
         prompt_dateobject_column = list(map(converter, Prompt_Local_Time_list))
     else:
         raise Exception("Unable to parse Actual_Prompt_Local_Time")
 
+    # drop float type in Actual_Prompt_Local_Time
     df_reprompt['Actual_Prompt_Local_DateTime'] = prompt_dateobject_column
+    df_reprompt = df_reprompt[df_reprompt['Actual_Prompt_Local_DateTime'] != "NF"]
+    df_reprompt.reset_index(inplace=True, drop=True)
 
     return df_reprompt
 
